@@ -5,7 +5,7 @@ test_that("can update", {
   file <- system.file("extdata", "tests", "subsetCars.Rmd",
                       package = "DataPackageR"
   )
-  file2 <- system.file("extdata", "tests", "extra.rmd",
+  file2 <- system.file("extdata", "tests", "extra.Rmd",
                        package = "DataPackageR"
   )
   expect_null(
@@ -20,14 +20,13 @@ test_that("can update", {
   package_build(file.path(tempdir(), "subsetCars"))
 
   #remove news.md and modify with the digest so it thinks there has been an update when rebuilt
-  file.remove(file.path(tempdir(),"subsetCars","news.md"))
+  file.remove(file.path(tempdir(), "subsetCars", "NEWS.md"))
   oldDigest<-DataPackageR:::.parse_data_digest(file.path(tempdir(),"subsetCars"))
   oldDigest$cars_over_20<-"123456789"
   DataPackageR:::.save_digest(oldDigest,file.path(tempdir(),"subsetCars"))
 
-  suppressWarnings({
-    expect_warning(build_res <- package_build(file.path(tempdir(), "subsetCars")))
-  })
+
+  expect_no_warning(build_res <- package_build(file.path(tempdir(), "subsetCars")))
   expect_identical(
     build_res,
     normalizePath(file.path(tempdir(),"subsetCars_1.0.tar.gz"),winslash = "/")
